# Kirby

Kafka-based Stream Processing Framework

[![Build Status](https://travis-ci.org/adimian/kirby.svg?branch=master)](https://travis-ci.org/adimian/kirby)
[![Coverage Status](https://coveralls.io/repos/github/adimian/kirby/badge.svg?branch=master)](https://coveralls.io/github/adimian/kirby?branch=master)
[![Documentation Status](https://readthedocs.org/projects/kirby/badge/?version=latest)](https://kirby.readthedocs.io/en/latest/?badge=latest)


Please see the official documentation here: http://kirby.readthedocs.io
